#!/bin/sh

# Change stream_ram path according with the OS
if [ -z "$1" ]
        then
        echo "Please set a valid OS. Valid options: angstrom, ubuntu"
        echo "e.g. './run_tests.sh angstrom' or './run_tests.sh ubuntu'"
        exit
fi

if [ "$1" = "angstrom" ]
        then
	STREAM_PATH=/var/lib/phoronix-test-suite/installed-tests/pts/stream-1.3.1/
elif [ "$1" = "ubuntu" ]; then
        STREAM_PATH=/home/ubuntu/.phoronix-test-suite/installed-tests/pts/stream-1.3.1/
fi

# Change the way how we take temperature log according with the CoM family
# To run on ubuntu, the lmsensor package must be installed through "sudo apt install lm-sensors"
if [ -z "$2" ]
	then
	echo "Please set a valid CoM family. Valid options: imx6, imx7, vybrid, t20, t30, tk1."
	echo "e.g. './run_tests.sh angstrom imx6' or './run_tests.sh ubuntu imx6'"
	exit
fi

case $2 in 
	imx6) COMMAND=cat SENSOR_PATH=/sys/devices/virtual/thermal/thermal_zone0/temp ;;
	imx7) COMMAND=cat SENSOR_PATH=/sys/devices/virtual/thermal/thermal_zone0/temp ;;
	vybrid) COMMAND=cat SENSOR_PATH=/sys/bus/iio/devices/iio:device1/in_temp_input ;;
	t20) COMMAND=cat SENSOR_PATH=/sys/bus/i2c/devices/4-004c/temp2_input ;;
	t30) COMMAND=cat SENSOR_PATH=/sys/bus/i2c/devices/4-004c/temp2_input ;;
	tk1) COMMAND=cat SENSOR_PATH=/sys/devices/virtual/thermal/thermal_zone4/temp ;;
	ubuntu) COMMAND=sensors SENSOR_PATH= ;;
esac

if [ -z "$HOME" ]
	then
	echo "Home directory not set, using /home/root"
	HOME=/home/root
fi

echo "Home directory is $HOME"
echo "Initial temperature is $($COMMAND $SENSOR_PATH)"                                                    

# Paths and logfiles - modify as you must
RESULTS=$HOME/results
LOGFILE=$RESULTS/info.log

cd $HOME
mkdir $RESULTS
touch $LOGFILE
# Added for T30 small pt problem with cpus, without this T30 works with just one CPU.
export OMP_NUM_THREADS=8

# Function to log the start of a test and write temperature value
log_start(){
	$COMMAND $SENSOR_PATH >> $LOGFILE
	echo "$(date) - Start $1 test" >> $LOGFILE
	echo "$(date) - Start $1 test"
}

# First test - encode-flac
log_start encode-flac
echo "n " | phoronix-test-suite benchmark pts/encode-flac > $RESULTS/encode_flac.log

# Second test - smallpt
log_start smallpt
echo "n " | phoronix-test-suite benchmark pts/smallpt > $RESULTS/smallpt.log

# Third test - c-ray
log_start c-ray
echo "n " | phoronix-test-suite benchmark pts/c-ray > $RESULTS/c-ray.log

# Fourth test - gtkperf
log_start gtkperf
printf "1\nn\n" | phoronix-test-suite benchmark pts/gtkperf > $RESULTS/gtkperf-combo-box.log
printf "2\nn\n" | phoronix-test-suite benchmark pts/gtkperf > $RESULTS/gtkperf-combo-box-entry.log

# Fifth test - stream
log_start stream
export OMP_NUM_THREADS=$(cat /proc/cpuinfo | grep processor | wc -l)
gcc -O -fopenmp -DSTREAM_ARRAY_SIZE=1000000 $STREAM_PATH/stream.c -o $HOME/stream-omp
$HOME/stream-omp > $RESULTS/stream-omp.log

sed -i '/ubi0_2/q' /etc/fstab

# Pack results
echo "$(date) - End tests" >> $LOGFILE
echo "$(date) - End tests"
tar cjvf results.tar.bz2 $RESULTS
